# automatically generated file, don't edit



# Copyright 2011 David Cantrell, derived from data from libphonenumber
# http://code.google.com/p/libphonenumber/
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
package Number::Phone::StubCountry::AM;
use base qw(Number::Phone::StubCountry);

use strict;
use warnings;
use utf8;
our $VERSION = 1.20181205223701;

my $formatters = [
                {
                  'pattern' => '(\\d{2})(\\d{6})',
                  'national_rule' => '(0$1)',
                  'leading_digits' => '
            1|
            47
          ',
                  'format' => '$1 $2'
                },
                {
                  'format' => '$1 $2',
                  'leading_digits' => '[23]',
                  'national_rule' => '(0$1)',
                  'pattern' => '(\\d{3})(\\d{5})'
                },
                {
                  'national_rule' => '0$1',
                  'format' => '$1 $2',
                  'leading_digits' => '
            [4-7]|
            88|
            9[13-9]
          ',
                  'pattern' => '(\\d{2})(\\d{6})'
                },
                {
                  'leading_digits' => '[89]',
                  'format' => '$1 $2 $3',
                  'national_rule' => '0 $1',
                  'pattern' => '(\\d{3})(\\d{2})(\\d{3})'
                }
              ];

my $validators = {
                'personal_number' => '',
                'specialrate' => '(80[1-4]\\d{5})|(90[016]\\d{5})',
                'fixed_line' => '
          (?:
            (?:
              1[0-2]|
              47
            )\\d|
            2(?:
              2[2-46]|
              3[1-8]|
              4[2-69]|
              5[2-7]|
              6[1-9]|
              8[1-7]
            )|
            3[12]2
          )\\d{5}
        ',
                'toll_free' => '800\\d{5}',
                'geographic' => '
          (?:
            (?:
              1[0-2]|
              47
            )\\d|
            2(?:
              2[2-46]|
              3[1-8]|
              4[2-69]|
              5[2-7]|
              6[1-9]|
              8[1-7]
            )|
            3[12]2
          )\\d{5}
        ',
                'voip' => '
          60(?:
            2[78]|
            3[5-9]|
            4[02-9]|
            5[0-46-9]|
            [6-8]\\d|
            90
          )\\d{4}
        ',
                'pager' => '',
                'mobile' => '
          (?:
            4[1349]|
            55|
            77|
            88|
            9[13-9]
          )\\d{6}
        '
              };
my %areanames = (
  37410 => "Yerevan\/Jrvezh",
  37411 => "Yerevan",
  37412 => "Yerevan",
  3742220 => "Abovyan\/Akunk\/Byureghavan\/Nor\ Gyugh\/Verin\ Ptghni\,\ Kotayk",
  3742221 => "Abovyan\/Akunk\/Byureghavan\/Nor\ Gyugh\/Verin\ Ptghni\,\ Kotayk",
  3742222 => "Abovyan\,\ Kotayk",
  3742223 => "Abovyan\,\ Kotayk",
  3742224 => "Abovyan\,\ Kotayk",
  3742225 => "Abovyan\/Arzni\/Arinj\/Geghashen\,\ Kotayk",
  3742226 => "Abovyan\,\ Kotayk",
  3742227 => "Garni\/Abovyan\,\ Kotayk",
  3742228 => "Abovyan\/Akunk\/Byureghavan\/Nor\ Gyugh\/Verin\ Ptghni\,\ Kotayk",
  37422281 => "Abovyan\/Arzni\/Arinj\/Geghashen\,\ Kotayk",
  37422290 => "Mayakovsky\,\ Kotayk",
  37422291 => "Balahovit\/Kamaris\,\ Kotayk",
  37422292 => "Zovk\/Abovyan\,\ Kotayk",
  37422293 => "Aramus\,\ Kotayk",
  37422294 => "Arzni\,\ Kotayk",
  37422295 => "Zovk\/Abovyan\,\ Kotayk",
  37422296 => "Ptghni\,\ Kotayk",
  37422297 => "Geghashen\,\ Kotayk",
  37422298 => "Arinj\,\ Kotayk",
  37422299 => "Kotayk",
  3742230 => "Hankavan\/Hrazdan\/Tsaghkadzor\,\ Kotayk",
  3742231 => "Hankavan\/Hrazdan\/Tsaghkadzor\,\ Kotayk",
  3742232 => "Hrazdan\,\ Kotayk",
  3742233 => "Hrazdan\,\ Kotayk",
  3742234 => "Hrazdan\,\ Kotayk",
  3742235 => "Tsaghkadzor\,\ Kotayk",
  3742236 => "Hrazdan\,\ Kotayk",
  37422370 => "Hrazdan\,\ Kotayk",
  37422371 => "Hrazdan\,\ Kotayk",
  37422372 => "Hrazdan\,\ Kotayk",
  37422373 => "Hrazdan\,\ Kotayk",
  37422374 => "Hrazdan\,\ Kotayk",
  37422375 => "Tsaghkadzor\,\ Kotayk",
  37422376 => "Tsaghkadzor\,\ Kotayk",
  37422377 => "Tsaghkadzor\,\ Kotayk",
  37422378 => "Tsaghkadzor\,\ Kotayk",
  37422379 => "Tsaghkadzor\,\ Kotayk",
  3742238 => "Hankavan\/Hrazdan\/Tsaghkadzor\,\ Kotayk",
  374223810 => "Hrazdan\,\ Kotayk",
  374223811 => "Hrazdan\,\ Kotayk",
  374223812 => "Hrazdan\,\ Kotayk",
  374223813 => "Hrazdan\,\ Kotayk",
  374223814 => "Hrazdan\,\ Kotayk",
  374223815 => "Tsaghkadzor\,\ Kotayk",
  374223816 => "Tsaghkadzor\,\ Kotayk",
  374223817 => "Tsaghkadzor\,\ Kotayk",
  374223818 => "Tsaghkadzor\,\ Kotayk",
  374223819 => "Tsaghkadzor\,\ Kotayk",
  37422390 => "Hrazdan\,\ Kotayk",
  37422391 => "Lernanist\,\ Kotayk",
  37422392 => "Hrazdan\,\ Kotayk",
  37422393 => "Meghradzor\,\ Kotayk",
  37422394 => "Pyunik\,\ Kotayk",
  37422395 => "Hrazdan\,\ Kotayk",
  37422396 => "Hrazdan\,\ Kotayk",
  37422397 => "Solak\,\ Kotayk",
  37422398 => "Bjni\,\ Kotayk",
  37422399 => "Hrazdan\,\ Kotayk",
  3742240 => "Kanakeravan\/Nor\ Geghi\/Nor\ Hajn\/Yeghvard\,\ Kotayk",
  3742241 => "Kanakeravan\/Nor\ Geghi\/Nor\ Hajn\/Yeghvard\,\ Kotayk",
  3742242 => "Yeghvard\,\ Kotayk",
  3742243 => "Yeghvard\,\ Kotayk",
  3742244 => "Nor\ Hajn\,\ Kotayk",
  3742245 => "Yeghvard\,\ Kotayk",
  37422452 => "Zovuni\,\ Kotayk",
  37422453 => "Proshyan\,\ Kotayk",
  37422454 => "Argel\,\ Kotayk",
  3742246 => "Yeghvard\,\ Kotayk",
  3742247 => "Yeghvard\/Nor\ Hajn\,\ Kotayk",
  3742248 => "Kanakeravan\/Nor\ Geghi\/Nor\ Hajn\/Yeghvard\,\ Kotayk",
  374224810 => "Yeghvard\,\ Kotayk",
  374224811 => "Yeghvard\,\ Kotayk",
  374224812 => "Yeghvard\,\ Kotayk",
  374224813 => "Yeghvard\,\ Kotayk",
  374224814 => "Yeghvard\,\ Kotayk",
  374224815 => "Nor\ Hajn\,\ Kotayk",
  374224816 => "Nor\ Hajn\,\ Kotayk",
  374224817 => "Nor\ Hajn\,\ Kotayk",
  374224818 => "Nor\ Hajn\,\ Kotayk",
  374224819 => "Nor\ Hajn\,\ Kotayk",
  3742249 => "Yeghvard\,\ Kotayk",
  374226 => "Charentsavan\,\ Kotayk",
  37422672 => "Arzakan\,\ Kotayk",
  37422675 => "Alapars\/Vardanavank\,\ Kotayk",
  3742310 => "Echmiadzin\/Musaler\/Parakar\/Zvartnots\,\ Armavir",
  3742311 => "Echmiadzin\/Musaler\/Parakar\/Zvartnots\,\ Armavir",
  3742312 => "Echmiadzin\,\ Armavir",
  3742313 => "Zvartnots\,\ Armavir",
  3742314 => "Echmiadzin\,\ Armavir",
  3742315 => "Echmiadzin\,\ Armavir",
  3742316 => "Echmiadzin\,\ Armavir",
  3742317 => "Zvartnots\,\ Armavir",
  3742318 => "Echmiadzin\/Musaler\/Parakar\/Zvartnots\,\ Armavir",
  37423181 => "Echmiadzin\,\ Armavir",
  374231817 => "Zvartnots\,\ Armavir",
  374231818 => "Zvartnots\,\ Armavir",
  374231819 => "Zvartnots\,\ Armavir",
  37423190 => "Baghramyan\,\ Armavir",
  37423191 => "Vache\,\ Armavir",
  37423192 => "Echmiadzin\,\ Armavir",
  37423193 => "Echmiadzin\,\ Armavir",
  37423194 => "Echmiadzin\,\ Armavir",
  37423195 => "Norakert\,\ Armavir",
  37423196 => "Echmiadzin\,\ Armavir",
  37423197 => "Echmiadzin\,\ Armavir",
  37423198 => "Jrarat\,\ Armavir",
  37423199 => "Khoronk\,\ Armavir",
  3742320 => "Aghdzq\/Ashtarak\/Karbi\/Oshakan\,\ Aragatsotn",
  3742321 => "Aghdzq\/Ashtarak\/Karbi\/Oshakan\,\ Aragatsotn",
  3742322 => "Ashtarak\,\ Aragatsotn",
  3742323 => "Ashtarak\,\ Aragatsotn",
  3742324 => "Ashtarak\/Byurakan\/Ohanavan\,\ Aragatsotn",
  3742325 => "Aghdzq\/Ashtarak\/Karbi\/Oshakan\,\ Aragatsotn",
  3742326 => "Ashtarak\,\ Aragatsotn",
  3742327 => "Aghdzq\/Ashtarak\/Karbi\/Oshakan\,\ Aragatsotn",
  3742328 => "Aghdzq\/Ashtarak\/Karbi\/Oshakan\,\ Aragatsotn",
  37423281 => "Ashtarak\/Byurakan\/Ohanavan\,\ Aragatsotn",
  3742329 => "Ashtarak\,\ Aragatsotn",
  37423290 => "Ohanavan\,\ Aragatsotn",
  37423294 => "Byurakan\,\ Aragatsotn",
  3742330 => "Baghramyan\/Lernagog\,\ Armavir",
  3742331 => "Baghramyan\/Lernagog\,\ Armavir",
  3742332 => "Baghramyan\,\ Armavir",
  3742333 => "Baghramyan\/Myasnikyan\,\ Armavir",
  3742334 => "Baghramyan\/Lernagog\,\ Armavir",
  3742335 => "Baghramyan\/Lernagog\,\ Armavir",
  3742336 => "Baghramyan\,\ Armavir",
  3742337 => "Baghramyan\,\ Armavir",
  37423374 => "Myasnikyan\,\ Armavir",
  37423375 => "Karakert\,\ Armavir",
  37423376 => "Dalarik\,\ Armavir",
  3742338 => "Baghramyan\/Lernagog\,\ Armavir",
  37423381 => "Baghramyan\/Myasnikyan\,\ Armavir",
  3742339 => "Baghramyan\,\ Armavir",
  374234 => "Ararat\/Vedi\,\ Ararat",
  3742340 => "Ararat\/Vedi\/Vosketap\,\ Ararat",
  3742341 => "Ararat\/Vedi\/Vosketap\,\ Ararat",
  3742345 => "Ararat\/Vedi\/Vosketap\,\ Ararat",
  374234510 => "Vedi\,\ Ararat",
  374234511 => "Vedi\,\ Ararat",
  374234512 => "Vedi\,\ Ararat",
  374234513 => "Vedi\,\ Ararat",
  374234514 => "Vedi\,\ Ararat",
  374234515 => "Ararat\/Urtsadzor\,\ Ararat",
  374234516 => "Ararat\/Urtsadzor\,\ Ararat",
  374234517 => "Ararat\/Urtsadzor\,\ Ararat",
  374234518 => "Ararat\/Urtsadzor\,\ Ararat",
  374234519 => "Ararat\/Urtsadzor\,\ Ararat",
  37423470 => "Vedi\,\ Ararat",
  37423471 => "Vedi\,\ Ararat",
  37423472 => "Vedi\,\ Ararat",
  37423473 => "Vedi\,\ Ararat",
  37423474 => "Vedi\,\ Ararat",
  37423475 => "Ararat\/Urtsadzor\,\ Ararat",
  37423476 => "Ararat\/Urtsadzor\,\ Ararat",
  37423477 => "Ararat\/Urtsadzor\,\ Ararat",
  37423478 => "Ararat\/Urtsadzor\,\ Ararat",
  37423479 => "Ararat\/Urtsadzor\,\ Ararat",
  37423481 => "Aygavan\,\ Ararat",
  37423486 => "Urtsadzor\,\ Ararat",
  37423492 => "Martirosyan\,\ Ararat",
  37423497 => "Pokr\ Vedi\,\ Ararat",
  37423498 => "Taperakan\,\ Ararat",
  3742350 => "Artashat\/Aygezard\/Dalar\/Kaghtsrashen\/Mkhchyan\/Shahumyan\,\ Ararat",
  3742351 => "Artashat\/Aygezard\/Dalar\/Kaghtsrashen\/Mkhchyan\/Shahumyan\,\ Ararat",
  3742352 => "Artashat\,\ Ararat",
  3742353 => "Artashat\/Norashen\,\ Ararat",
  3742354 => "Artashat\/Aygezard\/Dalar\/Kaghtsrashen\/Mkhchyan\/Shahumyan\,\ Ararat",
  3742355 => "Artashat\,\ Ararat",
  3742356 => "Artashat\,\ Ararat",
  3742357 => "Artashat\,\ Ararat",
  37423572 => "Arevshat\,\ Ararat",
  3742358 => "Artashat\/Aygezard\/Dalar\/Kaghtsrashen\/Mkhchyan\/Shahumyan\,\ Ararat",
  37423581 => "Artashat\/Norashen\,\ Ararat",
  3742359 => "Artashat\/Norashen\,\ Ararat",
  37423592 => "Norashen\,\ Ararat",
  37423593 => "Norashen\,\ Ararat",
  3742360 => "Ayntap\/Masis\/Nor\ Kharberd\/Norabats\,\ Ararat",
  3742361 => "Ayntap\/Masis\/Nor\ Kharberd\/Norabats\,\ Ararat",
  3742362 => "Masis\,\ Ararat",
  3742363 => "Ayntap\/Masis\,\ Ararat",
  3742364 => "Masis\,\ Ararat",
  3742365 => "Masis\,\ Ararat",
  3742366 => "Masis\,\ Ararat",
  3742367 => "Ayntap\/Masis\/Nor\ Kharberd\/Norabats\,\ Ararat",
  3742368 => "Ayntap\/Masis\/Nor\ Kharberd\/Norabats\,\ Ararat",
  37423681 => "Masis\,\ Ararat",
  3742369 => "Masis\,\ Ararat",
  37423699 => "Dashtavan\,\ Ararat",
  3742370 => "Araks\/Armavir\/Hoktember\/Lenughi\/Metsamor\/Zartonk\,\ Armavir",
  3742371 => "Araks\/Armavir\/Hoktember\/Lenughi\/Metsamor\/Zartonk\,\ Armavir",
  3742372 => "Armavir",
  3742373 => "Metsamor\,\ Armavir",
  3742374 => "Armavir",
  37423747 => "Araks\/Armavir\/Hoktember\/Lenughi\/Metsamor\/Zartonk\,\ Armavir",
  37423748 => "Araks\/Armavir\/Hoktember\/Lenughi\/Metsamor\/Zartonk\,\ Armavir",
  37423749 => "Araks\/Armavir\/Hoktember\/Lenughi\/Metsamor\/Zartonk\,\ Armavir",
  3742375 => "Armavir",
  3742376 => "Armavir",
  3742377 => "Armavir\/Mrgashat",
  37423771 => "Armavir",
  37423772 => "Mrgashat\,\ Armavir",
  37423779 => "Bambakashat\,\ Armavir",
  3742378 => "Araks\/Armavir\/Hoktember\/Lenughi\/Metsamor\/Zartonk\,\ Armavir",
  37423781 => "Armavir",
  3742379 => "Armavir\/Nalbandian",
  37423792 => "Nalbandian\,\ Armavir",
  37423794 => "Margara\,\ Armavir",
  37423796 => "Tandzut\,\ Armavir",
  37423798 => "Shenavan\,\ Armavir",
  374238 => "Ararat\/Avshar\/Surenavan\/Yeraskh",
  3742420 => "Maralik\/Sarnaghbyur\,\ Shirak",
  3742421 => "Maralik\/Sarnaghbyur\,\ Shirak",
  3742422 => "Maralik\,\ Shirak",
  3742423 => "Maralik\,\ Shirak",
  37424231 => "Sarnaghbyur\,\ Shirak",
  3742424 => "Maralik\,\ Shirak",
  3742425 => "Maralik\/Sarnaghbyur\,\ Shirak",
  3742426 => "Maralik\,\ Shirak",
  3742427 => "Maralik\/Sarnaghbyur\,\ Shirak",
  3742428 => "Maralik\/Sarnaghbyur\,\ Shirak",
  3742429 => "Maralik\,\ Shirak",
  37424293 => "Shirakavan\,\ Shirak",
  37424297 => "Ani\ Kayaran\,\ Shirak",
  37424300 => "Akhuryan\/Arapi\/Kamo\/Musayelyan\,\ Shirak",
  3742440 => "Artik\/Pemzashen\,\ Shirak",
  3742441 => "Artik\/Pemzashen\,\ Shirak",
  3742442 => "Artik\,\ Shirak",
  3742443 => "Artik\,\ Shirak",
  3742444 => "Artik\/Panik\,\ Shirak",
  3742445 => "Artik\,\ Shirak",
  3742446 => "Artik\,\ Shirak",
  3742447 => "Artik\/Pemzashen\,\ Shirak",
  3742448 => "Artik\/Pemzashen\,\ Shirak",
  37424481 => "Artik\/Panik\,\ Shirak",
  3742449 => "Artik\,\ Shirak",
  37424492 => "Panik\,\ Shirak",
  37424495 => "Arevshat\,\ Shirak",
  37424496 => "Mets\ Mantash\,\ Shirak",
  374245 => "Ashotsk\,\ Shirak",
  374246 => "Amasia\,\ Shirak",
  374249 => "Talin\,\ Aragatsotn",
  3742494 => "Talin\/Aragats\/Katnaghbyur\/Mastara\,\ Aragatsotn",
  37424973 => "Katnaghbyur\,\ Aragatsotn",
  37424981 => "Talin\/Aragats\/Katnaghbyur\/Mastara\,\ Aragatsotn",
  3742499 => "Aragatsavan\/Talin\,\ Aragatsotn",
  37424995 => "Aragats\,\ Aragatsotn",
  37424996 => "Nerkin\ Bazmaberd\,\ Aragatsotn",
  37424997 => "Mastara\,\ Aragatsotn",
  374252 => "Aparan\,\ Aragatsotn",
  3742524 => "Aparan\/Artavan\/Kuchak\,\ Aragatsotn",
  37425251 => "Kuchak\,\ Aragatsotn",
  37425281 => "Aparan\/Artavan\/Kuchak\,\ Aragatsotn",
  37425291 => "Kuchak\,\ Aragatsotn",
  37425295 => "Artavan\,\ Aragatsotn",
  3742530 => "Alaverdi\/Odzun\/Tsaghkashat\/Tumanyan\,\ Lori",
  3742531 => "Alaverdi\/Odzun\/Tsaghkashat\/Tumanyan\,\ Lori",
  3742532 => "Alaverdi\,\ Lori",
  3742533 => "Alaverdi\,\ Lori",
  3742534 => "Alaverdi\,\ Lori",
  3742535 => "Alaverdi\,\ Lori",
  37425352 => "Akhtala\,\ Lori",
  37425353 => "Shnogh\,\ Lori",
  37425356 => "Chochkan\,\ Lori",
  37425357 => "Tumanyan\,\ Lori",
  3742536 => "Alaverdi\,\ Lori",
  3742537 => "Alaverdi\/Akhtala\/Tumanyan\,\ Lori",
  3742538 => "Alaverdi\/Odzun\/Tsaghkashat\/Tumanyan\,\ Lori",
  37425381 => "Alaverdi\/Akhtala\/Tumanyan\,\ Lori",
  3742539 => "Alaverdi\/Odzun\/Tsaghkashat\/Tumanyan\,\ Lori",
  374254 => "Tashir\,\ Lori",
  3742543 => "Tashir\/Metsavan\,\ Lori",
  37425481 => "Tashir\/Metsavan\,\ Lori",
  3742549 => "Tashir\/Metsavan\,\ Lori",
  37425494 => "Metsavan\,\ Lori",
  374255 => "Spitak\,\ Lori",
  3742560 => "Bovadzor\/Stepanavan\,\ Lori",
  3742561 => "Bovadzor\/Stepanavan\,\ Lori",
  3742562 => "Stepanavan\,\ Lori",
  3742563 => "Stepanavan\,\ Lori",
  3742564 => "Stepanavan\,\ Lori",
  3742565 => "Bovadzor\/Stepanavan\,\ Lori",
  3742566 => "Stepanavan\,\ Lori",
  3742567 => "Bovadzor\/Stepanavan\,\ Lori",
  3742568 => "Bovadzor\/Stepanavan\,\ Lori",
  37425681 => "Stepanavan\,\ Lori",
  3742569 => "Stepanavan\,\ Lori",
  37425691 => "Kurtan\,\ Lori",
  37425694 => "Agarak\,\ Lori",
  37425695 => "Lejan\,\ Lori",
  374257 => "Aragats\,\ Aragatsotn",
  3742570 => "Tsakhkahovit\,\ Aragatsotn",
  3742572 => "Tsakhkahovit\,\ Aragatsotn",
  3742573 => "Tsakhkahovit\,\ Aragatsotn",
  3742576 => "Tsakhkahovit\,\ Aragatsotn",
  37425781 => "Tsakhkahovit\,\ Aragatsotn",
  374261 => "Sevan\,\ Gegharkunik",
  374262 => "Martuni\,\ Gegharkunik",
  3742623 => "Martuni\/Vardenik\,\ Gegharkunik",
  37426252 => "Vardenik\,\ Gegharkunik",
  37426253 => "Vardenik\,\ Gegharkunik",
  37426272 => "Lichk\,\ Gegharkunik",
  37426281 => "Martuni\/Vardenik\,\ Gegharkunik",
  37426299 => "Eranos\,\ Gegharkunik",
  3742630 => "Azatamut\/Getahovit\/Ijevan\/Yenokavan\,\ Tavush",
  3742631 => "Azatamut\/Getahovit\/Ijevan\/Yenokavan\,\ Tavush",
  3742632 => "Ijevan\/Aygehovit\/Achajur\,\ Tavush",
  3742633 => "Ijevan\,\ Tavush",
  3742634 => "Ijevan\,\ Tavush",
  3742635 => "Azatamut\/Getahovit\/Ijevan\/Yenokavan\,\ Tavush",
  3742636 => "Ijevan\,\ Tavush",
  3742637 => "Ijevan\,\ Tavush",
  37426374 => "Aygehovit\,\ Tavush",
  3742638 => "Azatamut\/Getahovit\/Ijevan\/Yenokavan\,\ Tavush",
  37426381 => "Ijevan\/Aygehovit\/Achajur\,\ Tavush",
  3742639 => "Ijevan\,\ Tavush",
  37426392 => "Achajur\,\ Tavush",
  37426397 => "Azatamut\,\ Tavush",
  374264 => "Gavar\,\ Gegharkunik",
  3742640 => "Gavar\/Sarukhan\,\ Gegharkunik",
  3742641 => "Gavar\/Sarukhan\,\ Gegharkunik",
  3742647 => "Gavar\/Sarukhan\,\ Gegharkunik",
  3742648 => "Gavar\/Sarukhan\,\ Gegharkunik",
  374265 => "Tchambarak\,\ Gegharkunik",
  3742654 => "Tchambarak\/Vahan\,\ Gegharkunik",
  37426581 => "Tchambarak\/Vahan\,\ Gegharkunik",
  37426596 => "Vahan\,\ Gegharkunik",
  3742660 => "Berdavan\/Koghb\/Noyemberyan\,\ Tavush",
  3742661 => "Berdavan\/Koghb\/Noyemberyan\,\ Tavush",
  3742662 => "Noyemberyan\,\ Tavush",
  3742663 => "Noyemberyan\/Voskepar\/Koti\/Koghb\,\ Tavush",
  3742664 => "Berdavan\/Koghb\/Noyemberyan\,\ Tavush",
  3742665 => "Koghb\/Noyemberyan\,\ Tavush",
  37426652 => "Koghb\,\ Tavush",
  37426653 => "Koghb\,\ Tavush",
  3742666 => "Noyemberyan\,\ Tavush",
  3742667 => "Berdavan\/Noyemberyan\,\ Tavush",
  3742668 => "Berdavan\/Koghb\/Noyemberyan\,\ Tavush",
  37426681 => "Noyemberyan\/Voskepar\/Koti\/Koghb\,\ Tavush",
  37426690 => "Noyemberyan\,\ Tavush",
  37426691 => "Noyemberyan\,\ Tavush",
  37426692 => "Archis\,\ Tavush",
  37426693 => "Baghanis\,\ Tavush",
  37426694 => "Noyemberyan\,\ Tavush",
  37426695 => "Zorakan\,\ Tavush",
  37426696 => "Voskepar\,\ Tavush",
  37426697 => "Noyemberyan\,\ Tavush",
  37426698 => "Noyemberyan\,\ Tavush",
  37426699 => "Koti\,\ Tavush",
  3742670 => "Aygepar\/Berd\,\ Tavush",
  3742671 => "Aygepar\/Berd\,\ Tavush",
  3742672 => "Berd\,\ Tavush",
  3742673 => "Berd\/Mosesgegh\/Navur\/Norashen\,\ Tavush",
  3742674 => "Aygepar\/Berd\,\ Tavush",
  3742675 => "Artsvaberd\/Berd\,\ Tavush",
  3742676 => "Berd\,\ Tavush",
  3742677 => "Berd\,\ Tavush",
  3742678 => "Aygepar\/Berd\,\ Tavush",
  37426781 => "Berd\/Mosesgegh\/Navur\/Norashen\,\ Tavush",
  3742679 => "Berd\,\ Tavush",
  37426791 => "Navur\,\ Tavush",
  37426794 => "Tovuz\,\ Tavush",
  37426796 => "Mosesgegh\,\ Tavush",
  37426797 => "Norashen\,\ Tavush",
  3742680 => "Dilijan\,\ Tavush",
  3742682 => "Dilijan\,\ Tavush",
  3742683 => "Dilijan\,\ Tavush",
  3742684 => "Dilijan\/Haghartsin\/Teghut\,\ Tavush",
  3742686 => "Dilijan\,\ Tavush",
  37426881 => "Dilijan\/Haghartsin\/Teghut\,\ Tavush",
  3742689 => "Dilijan\,\ Tavush",
  37426895 => "Haghartsin\,\ Tavush",
  37426897 => "Teghut\,\ Tavush",
  374269 => "Vardenis\,\ Gegharkunik",
  3742810 => "Getap\/Salli\/Yeghegnadzor\,\ Vayots\ dzor",
  3742811 => "Getap\/Salli\/Yeghegnadzor\,\ Vayots\ dzor",
  3742812 => "Yeghegnadzor\,\ Vayots\ dzor",
  3742813 => "Yeghegnadzor\/Malishka\/Shatin\,\ Vayots\ dzor",
  3742814 => "Getap\/Salli\/Yeghegnadzor\,\ Vayots\ dzor",
  3742815 => "Yeghegnadzor\,\ Vayots\ dzor",
  37428151 => "Khachik\,\ Vayots\ dzor",
  3742816 => "Yeghegnadzor\,\ Vayots\ dzor",
  3742817 => "Getap\/Salli\/Yeghegnadzor\,\ Vayots\ dzor",
  3742818 => "Getap\/Salli\/Yeghegnadzor\,\ Vayots\ dzor",
  37428181 => "Yeghegnadzor\/Malishka\/Shatin\,\ Vayots\ dzor",
  37428190 => "Yeghegnadzor\,\ Vayots\ dzor",
  37428191 => "Arpi\,\ Vayots\ dzor",
  37428192 => "Yeghegnadzor\,\ Vayots\ dzor",
  37428193 => "Aghavnadzor\,\ Vayots\ dzor",
  37428194 => "Areni\,\ Vayots\ dzor",
  37428195 => "Malishka\,\ Vayots\ dzor",
  37428196 => "Yeghegnadzor\,\ Vayots\ dzor",
  37428197 => "Yelpin\,\ Vayots\ dzor",
  37428198 => "Rind\,\ Vayots\ dzor",
  37428199 => "Shatin\,\ Vayots\ dzor",
  374282 => "Vayk\,\ Vayots\ dzor",
  3742830 => "Sisian\,\ Syunik",
  3742832 => "Sisian\,\ Syunik",
  3742833 => "Sisian\,\ Syunik",
  37428351 => "Sisian\,\ Syunik",
  3742836 => "Sisian\,\ Syunik",
  3742837 => "Sisian\,\ Syunik",
  37428375 => "Tasik\,\ Syunik",
  3742838 => "Sisian\,\ Syunik",
  3742839 => "Sisian\,\ Syunik",
  37428396 => "Angehakot\,\ Syunik",
  374284 => "Goris\,\ Syunik",
  3742840 => "Goris\/Verishen\,\ Syunik",
  3742841 => "Goris\/Verishen\,\ Syunik",
  37428427 => "Verishen\,\ Syunik",
  3742847 => "Goris\/Verishen\,\ Syunik",
  3742848 => "Goris\/Verishen\,\ Syunik",
  37428491 => "Harzhis\,\ Syunik",
  37428494 => "Khndzoresk\,\ Syunik",
  37428495 => "Shinuhayr\,\ Syunik",
  37428499 => "Kornidzor\,\ Syunik",
  3742850 => "Davit\ Bek\/Kajaran\/Kapan\,\ Syunik",
  3742851 => "Davit\ Bek\/Kajaran\/Kapan\,\ Syunik",
  3742852 => "Kapan\,\ Syunik",
  3742853 => "Kajaran\,\ Syunik",
  37428540 => "Kapan\,\ Syunik",
  37428541 => "Kapan\,\ Syunik",
  37428542 => "Kapan\,\ Syunik",
  37428543 => "Kapan\,\ Syunik",
  37428544 => "Kapan\,\ Syunik",
  37428545 => "Kajaran\,\ Syunik",
  37428546 => "Kajaran\,\ Syunik",
  37428547 => "Kajaran\,\ Syunik",
  37428548 => "Kajaran\,\ Syunik",
  37428549 => "Kajaran\,\ Syunik",
  3742855 => "Kapan\,\ Syunik",
  3742856 => "Kapan\,\ Syunik",
  3742857 => "Davit\ Bek\/Kajaran\/Kapan\,\ Syunik",
  3742858 => "Davit\ Bek\/Kajaran\/Kapan\,\ Syunik",
  374285810 => "Kapan\,\ Syunik",
  374285811 => "Kapan\,\ Syunik",
  374285812 => "Kapan\,\ Syunik",
  374285813 => "Kapan\,\ Syunik",
  374285814 => "Kapan\,\ Syunik",
  374285815 => "Kajaran\,\ Syunik",
  374285816 => "Kajaran\,\ Syunik",
  374285817 => "Kajaran\,\ Syunik",
  374285818 => "Kajaran\,\ Syunik",
  374285819 => "Kajaran\,\ Syunik",
  3742859 => "Kapan\,\ Syunik",
  3742860 => "Meghri\/Agarak\,\ Syunik",
  3742861 => "Meghri\/Agarak\,\ Syunik",
  3742862 => "Agarak\,\ Syunik",
  3742863 => "Meghri\,\ Syunik",
  3742864 => "Meghri\,\ Syunik",
  3742865 => "Agarak\/Shvanidzor\,\ Syunik",
  3742866 => "Meghri\,\ Syunik",
  3742867 => "Meghri\/Agarak\,\ Syunik",
  3742868 => "Meghri\/Agarak\,\ Syunik",
  374286810 => "Meghri\,\ Syunik",
  374286811 => "Meghri\,\ Syunik",
  374286812 => "Meghri\,\ Syunik",
  374286813 => "Meghri\,\ Syunik",
  374286814 => "Meghri\,\ Syunik",
  374286815 => "Agarak\/Meghri\,\ Syunik",
  374286816 => "Agarak\/Meghri\,\ Syunik",
  374286817 => "Agarak\/Meghri\,\ Syunik",
  374286818 => "Agarak\/Meghri\,\ Syunik",
  374286819 => "Agarak\/Meghri\,\ Syunik",
  3742869 => "Meghri\,\ Syunik",
  37428695 => "Shvanidzor\,\ Syunik",
  374287 => "Jermuk\,\ Vayots\ dzor",
  3742873 => "Jermuk\/Gndevaz\,\ Vayots\ dzor",
  37428781 => "Jermuk\/Gndevaz\,\ Vayots\ dzor",
  37428794 => "Gndevaz\,\ Vayots\ dzor",
  374312 => "Gyumri\,\ Shirak",
  3743120 => "Gyumri\/Akhuryan\,\ Shirak",
  3743121 => "Gyumri\/Akhuryan\,\ Shirak",
  3743127 => "Akhuryan\,\ Shirak",
  37431280 => "Akhuryan\,\ Shirak",
  37431281 => "Akhuryan\,\ Shirak",
  37431282 => "Akhuryan\,\ Shirak",
  37431283 => "Akhuryan\,\ Shirak",
  37431284 => "Akhuryan\,\ Shirak",
  374312859 => "Akhuryan\,\ Shirak",
  37431286 => "Gyumri\/Akhuryan\,\ Shirak",
  37431287 => "Gyumri\/Akhuryan\,\ Shirak",
  37431288 => "Gyumri\/Akhuryan\,\ Shirak",
  37431289 => "Gyumri\/Akhuryan\,\ Shirak",
  374322 => "Vanadzor\,\ Lori",
  3743220 => "Vanadzor\/Gugark\,\ Lori",
  3743221 => "Vanadzor\/Gugark\,\ Lori",
  3743228 => "Vanadzor\/Gugark\,\ Lori",
  37432293 => "Pambak\,\ Lori",
  37432294 => "Lernapat\,\ Lori",
  37432295 => "Yeghegnut\,\ Lori",
  37432296 => "Margahovit\,\ Lori",
  37432297 => "Dzoraget\,\ Lori",
  37432298 => "Lermontovo\,\ Lori",
  37432299 => "Vahagni\,\ Lori",
  374470 => "Nagorno\-Karabakh",
  374471 => "Stepanakert",
  374472 => "Nagorno\-Karabakh",
  374473 => "Nagorno\-Karabakh",
  374474 => "Martakert",
  374475 => "Hadrut",
  374476 => "Askeran",
  374477 => "Shushi",
  37447732 => "Berdzor\/Kashatagh",
  374478 => "Martuni",
  374479 => "Stepanakert",
);
    sub new {
      my $class = shift;
      my $number = shift;
      $number =~ s/(^\+374|\D)//g;
      my $self = bless({ number => $number, formatters => $formatters, validators => $validators, areanames => \%areanames}, $class);
      return $self if ($self->is_valid());
      $number =~ s/^(?:0)//;
      $self = bless({ number => $number, formatters => $formatters, validators => $validators, areanames => \%areanames}, $class);
      return $self->is_valid() ? $self : undef;
    }
1;