# automatically generated file, don't edit



# Copyright 2011 David Cantrell, derived from data from libphonenumber
# http://code.google.com/p/libphonenumber/
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
package Number::Phone::StubCountry::CW;
use base qw(Number::Phone::StubCountry);

use strict;
use warnings;
use utf8;
our $VERSION = 1.20181205223703;

my $formatters = [
                {
                  'leading_digits' => '[3467]',
                  'format' => '$1 $2',
                  'pattern' => '(\\d{3})(\\d{4})'
                },
                {
                  'pattern' => '(\\d)(\\d{3})(\\d{4})',
                  'leading_digits' => '9[4-8]',
                  'format' => '$1 $2 $3'
                }
              ];

my $validators = {
                'voip' => '',
                'pager' => '955\\d{5}',
                'mobile' => '
          9(?:
            5(?:
              [12467]\\d|
              3[01]
            )|
            6(?:
              [15-9]\\d|
              3[01]
            )
          )\\d{4}
        ',
                'fixed_line' => '
          9(?:
            (?:
              [48]\\d|
              50
            )\\d|
            7(?:
              2[0-24]|
              [34]\\d|
              6[35-7]|
              77|
              8[7-9]
            )
          )\\d{4}
        ',
                'specialrate' => '(60[0-2]\\d{4})',
                'personal_number' => '',
                'toll_free' => '',
                'geographic' => '
          9(?:
            (?:
              [48]\\d|
              50
            )\\d|
            7(?:
              2[0-24]|
              [34]\\d|
              6[35-7]|
              77|
              8[7-9]
            )
          )\\d{4}
        '
              };
my %areanames = (
  599318 => "St\.\ Eustatius",
  599416 => "Saba",
  59971 => "Bonaire",
  59975 => "Bonaire",
);
    sub new {
      my $class = shift;
      my $number = shift;
      $number =~ s/(^\+599|\D)//g;
      my $self = bless({ number => $number, formatters => $formatters, validators => $validators, areanames => \%areanames}, $class);
        return $self->is_valid() ? $self : undef;
    }
1;