# automatically generated file, don't edit



# Copyright 2011 David Cantrell, derived from data from libphonenumber
# http://code.google.com/p/libphonenumber/
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
package Number::Phone::StubCountry::SL;
use base qw(Number::Phone::StubCountry);

use strict;
use warnings;
use utf8;
our $VERSION = 1.20181205223704;

my $formatters = [
                {
                  'national_rule' => '(0$1)',
                  'format' => '$1 $2',
                  'leading_digits' => '[2-9]',
                  'pattern' => '(\\d{2})(\\d{6})'
                }
              ];

my $validators = {
                'mobile' => '
          (?:
            2[15]|
            3[013-5]|
            4[04]|
            5[05]|
            66|
            7[5-9]|
            8[08]|
            99
          )\\d{6}
        ',
                'pager' => '',
                'voip' => '',
                'geographic' => '[235]2[2-4][2-9]\\d{4}',
                'toll_free' => '',
                'personal_number' => '',
                'specialrate' => '',
                'fixed_line' => '[235]2[2-4][2-9]\\d{4}'
              };
my %areanames = (
  23222 => "Freetown",
  23232 => "Bo\/Kenema",
  23252 => "Makeni\/Koidu",
);
    sub new {
      my $class = shift;
      my $number = shift;
      $number =~ s/(^\+232|\D)//g;
      my $self = bless({ number => $number, formatters => $formatters, validators => $validators, areanames => \%areanames}, $class);
      return $self if ($self->is_valid());
      $number =~ s/^(?:0)//;
      $self = bless({ number => $number, formatters => $formatters, validators => $validators, areanames => \%areanames}, $class);
      return $self->is_valid() ? $self : undef;
    }
1;